const data = {
  init: false,
  modules: [],
};
export default data;

export const setModules = (modules) => {
  data.init = true;
  data.modules = modules;
};

export const getModules = () => {
  return data.modules;
};

export const isInited = () => {
  return data.init;
};

// noinspection EqualityComparisonWithCoercionJS
export const getModule = id => data.modules.filter(m => m.id == id).pop(); // eslint-disable-line eqeqeq, max-len

export const getPath = (id) => {
  const module = getModule(id);
  if (module.parent) {
    const parent = getModule(module.parent);
    return [...getPath(parent.id), id];
  } else {
    return [id];
  }
};

export const getChildren = (id) => {
  const children = [];
  for (const module of data.modules) {
    // noinspection EqualityComparisonWithCoercionJS
    if (module.parent == id) { // eslint-disable-line eqeqeq
      children.push(module);
    }
  }
  return children;
};

export function foreachModule(callback) {
  for (const module of data.modules) {
    callback(module);
  }
}

export const setModuleConfigure = (id, configure) => {
  const module = getModule(id);
  if (module) {
    module.configure = configure;
  }
};

export const getModuleConfigure = (id) => {
  const module = getModule(id);
  return module ? module.configure : null;
};

