import _ from 'lodash';
import resolvePathname from 'resolve-pathname';

export function makePath(base, path) {
  if (path.startsWith('/')) {
    return path;
  }
  const basePath = base.endsWith('/') ? base : `${base}/`;
  return resolvePathname(path, basePath);
}

const checkThis = (theThis) => {
  if (!theThis || !theThis.props) {
    throw new Error('The this is not a component.');
  }
  if (!theThis.props.router) {
    throw new Error('please use withRouter.');
  }
};

const getBase = (theThis) => {
  if (theThis.props.location) {
    return theThis.props.location.pathname;
  } else if (typeof window !== 'undefined') {
    return window.location.pathname; // eslint-disable-line no-undef
  } else {
    throw new Error('can not find base path!');
  }
};

const dealWithRoute = (theThis, route) => {
  const base = getBase(theThis);
  if (_.isString(route)) {
    return makePath(base, route);
  } else if (route && route.pathname) {
    return {
      ...route,
      pathname: makePath(base, route.pathname),
    };
  } else {
    throw new Error('invalid route');
  }
};

export function push(theThis, pathOrLoc) {
  checkThis(theThis);
  const route = dealWithRoute(theThis, pathOrLoc);
  return theThis.props.router.push(route);
}

export function replace(theThis, pathOrLoc) {
  checkThis(theThis);
  const route = dealWithRoute(theThis, pathOrLoc);
  return theThis.props.router.replace(route);
}

export function go(theThis, n) {
  checkThis(theThis);
  return theThis.props.router.go(n);
}

export function goBack(theThis) {
  checkThis(theThis);
  return theThis.props.router.goBack();
}

export function goForward(theThis) {
  checkThis(theThis);
  return theThis.props.router.goForward();
}
